==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_t4() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return ChaikinOscillatorIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.uq));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.uq, a);
        }
        uc() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.up));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.up, a);
        }
        t9() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = /*@__PURE__*/ markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.uq = /*@__PURE__*/ StrategyBasedIndicator.uo(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.up = /*@__PURE__*/ StrategyBasedIndicator.uk(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();

==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return ChaikinOscillatorIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.u3));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.u3, a);
        }
        up() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.u2));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.u2, a);
        }
        um() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = /*@__PURE__*/ markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.u3 = /*@__PURE__*/ StrategyBasedIndicator.u1(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.u2 = /*@__PURE__*/ StrategyBasedIndicator.ux(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();
